<template>
  <div class="myapps-iframe">
    <mt-header class="home-header" style="background:white;" v-if="showBack">
      <a @click="doBack()" slot="left" style="color:#666666;">
        <mt-button icon="back"></mt-button>
      </a>
    </mt-header>
    <!-- 全局的消息框 -->
    <mt-popup 
      v-model="popup.visible" 
      :position="popup.position" 
      :modal="false" 
      pop-transition="popup-fade">{{popup.message}}</mt-popup>
      <keep-alive include="view-delegate,view-listview">
        <component
          :key="$route.query.actionContent"
          :is="contentType()" 
          v-if="hackReset" 
          :openParams="params" 
          :popupVisible="popupVisible" 
          v-bind="$attrs" 
          v-on="$listeners"
          @onAction="doAction"/>
      </keep-alive>
  </div>
</template>

<script>
import view_delegate from "@/components/view_delegate.vue";
import form_normalform from "@/components/form_normalform.vue";
import profile from "@/components/profile.vue";
import information from "@/components/information.vue";
import main_management from "@/components/main_management.vue";
import main_pending from "@/components/main_pending.vue";
import main_processing from "@/components/main_processing.vue";
import common_linkcontent from "@/components/common_linkcontent"

export default {
  name: "obpm-open-container",
  props: ["openParams"],
  components: {
    view_delegate,
    form_normalform,
    profile,
    information,
    main_management,
    main_pending,
    main_processing,
    common_linkcontent,
  },
  created() {
    let queryData = this.$route.query;
	  if(queryData.showBack){ //本来外链显示返回栏的，但是如果外链是手机端本身，按钮显示不全
      this.showBack = false//true;
    }
    let openParams = {
      linkType: queryData.linkType,
      appId: queryData.appId || this.$root.appid,
      actionContent: queryData.actionContent,
      _select: queryData.docId ? queryData.docId : queryData._select,
      showtype: queryData.showtype ? queryData.showtype:'',
      parentId: queryData.parentId ? queryData.parentId:'', //包含元素时判断是否有parentId
      isRelate: queryData.isRelate ? queryData.isRelate:'',
      formId: queryData.formId ? queryData.formId:'',
      viewId: queryData.viewId,
      searchdata: queryData.searchData,
      templateForm: queryData.templateForm ? queryData.templateForm:'',
      realformId: queryData.realformId ? queryData.realformId:'',
      _treeviewToview: queryData._treeviewToview ? queryData._treeviewToview:'',
      isWidgetChartView: queryData.isWidgetChartView ? queryData.isWidgetChartView:'', //判断是否是widget统计图
      urlParams: queryData.urlParams ? queryData.urlParams:'', //判断表单跳转按钮是否带有参数
    };
    let formParams = '';
    let obj = queryData;
    if(queryData.isNewCreate) {
      openParams.isNewCreate = queryData.isNewCreate;
    }
    if(queryData.runAfterParams) {
      openParams.runAfterParams = queryData.runAfterParams;
    }
    for(let key in obj) {
      if(
        key != 'name' &&
        key != 'searchData' && 
        key != 'showtype' && 
        key != 'realformId' && 
        key != 'templateForm' && 
        key != 'urlParams' && 
        key != 'exparams' &&
        key != 'isNewCreate' &&
        key != 'runAfterParams' &&
        key != 'queryString') {
        if(obj[key]) {
          formParams += "&" + key + '=' + obj[key];
        }
      }
    }
    if(obj.exparams) {
      if(formParams) {
        formParams = formParams + "" + obj.exparams;
      }else {
        formParams = obj.exparams;
      }
    }
    openParams.formParams = formParams;
    if(obj.queryString) { //菜单自带的参数
      openParams.queryString = obj.queryString;
    }
    this.doAction(openParams);
  },

  mounted() {

  },

  activated() {

  },

  watch: {
    '$route' (to) { //监听路由是否变化
      console.log("opener--路由->",to);
    },
  },

  beforeRouteEnter (to, from, next) {
    next();
  },

  beforeRouteUpdate (to, from, next) {
    this.searchdata = from.query.searchData
    if(from.query.searchData && JSON.stringify(from.query.searchData) !== '{}' && Object.keys(from.query.searchData).length) {
      if(to.query.searchData && JSON.stringify(to.query.searchData) !== '{}') {
        from.query.searchData = to.query.searchData;
      }else {
        to.query.searchData = from.query.searchData;
        if(to.query.searchData === '[object Object]') {
          to.query.searchData = {};
        }
      }
      
    }
    next();
  },
  beforeRouteLeave(to, from, next) {
    next();
  },
  data: function() {
    return {
      title: "...",
      params: null,
      paramsHistory: [],
      hackReset: true,
      popupVisible: false,
      popup: {
        position: "top",
        visible: false,
        message: "",
      },
      searchdata:'',
	  showBack: false
    };
  },

  methods: {
    //重建时加载
    reloading() {
      this.hackReset = false
      this.$nextTick(() => {
        this.hackReset = true
      })
    },

    showPopup: function({action, message, timeout}){
      if (action == 'info') {
      this.popup.message = message;
      this.popup.position = "top";  
      }
      this.popup.visible = true;
      timeout = timeout || 2000;
      setTimeout(() => {
        this.popup.visible = false;
      }, timeout);
    },
    
    contentType: function() {
      let compName;
      switch (this.params.linkType) {
        case "00":
          //表单
          compName = "form_normalform";
          break;
        case "01":
          //列表视图
          compName = "view_delegate";
          break;
        case "02":
          //个人设置
          compName = "profile";
          break;
        case "03":
          //信息管理
          compName = "information";
          break;
        case "04":
          //系统设置
          compName = "main_management";
          break;
        case "05":
          //发起新建
          compName = "main_pending";
          break;
        case "06":
          //我的待办
          compName = "main_pending";
          break;
        case "07":
          //经办跟踪
          compName = "main_processing";
          break;
        case "08":
          //仪表分析
          compName = "main_pending";
          break;
        case "103":
          compName = "common_linkcontent";
          break;
        default:
          break;
      }
      return compName;
    },

    doAction: function(params) {
      if (params && params.action == 'info') {
        //显示消息
        this.showPopup(params);
      }else {
        this.paramsHistory.push(params);
        this.params = params;
      }
    },

    doBack: function() {
      if (this.paramsHistory.length > 0) {
        this.paramsHistory.pop();
      }
      if (this.paramsHistory.length > 0) {
        this.params = this.paramsHistory[this.paramsHistory.length - 1];
      } else {
        if (this.$parent.onCloseBtnClick) {
          this.$parent.onCloseBtnClick(this.params);
        }
        else {
          this.$router.go(-1)
        }
      }
    },

  }
};
</script>

